Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(424)

Unified Diff: chrome/browser/profiles/profile_metrics.h

Issue 1191453002: Implement "open link as user" context menu entry (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: updates Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_metrics.h
diff --git a/chrome/browser/profiles/profile_metrics.h b/chrome/browser/profiles/profile_metrics.h
index d9c4975a1c35434c4d1ece18aadbdfba0f14bbdb..0b3c71fc4bb7f082b4e044070f6bf9799aae60f6 100644
--- a/chrome/browser/profiles/profile_metrics.h
+++ b/chrome/browser/profiles/profile_metrics.h
@@ -62,15 +62,16 @@ class ProfileMetrics {
// Enum for counting the ways user profiles and menus were opened.
enum ProfileOpen {
- NTP_AVATAR_BUBBLE = 0, // User opens avatar menu from NTP
- ICON_AVATAR_BUBBLE, // User opens the avatar menu from button
- SWITCH_PROFILE_ICON, // User switches profiles from icon menu
- SWITCH_PROFILE_MENU, // User switches profiles from menu bar
- SWITCH_PROFILE_DOCK, // User switches profiles from dock (Mac-only)
- OPEN_USER_MANAGER, // User opens the User Manager
- SWITCH_PROFILE_MANAGER, // User switches profiles from the User Manager
- SWITCH_PROFILE_UNLOCK, // User switches to lockd profile via User Manager
- SWITCH_PROFILE_GUEST, // User switches to guest profile
+ NTP_AVATAR_BUBBLE = 0, // User opens avatar menu from NTP
+ ICON_AVATAR_BUBBLE, // User opens the avatar menu from button
+ SWITCH_PROFILE_ICON, // User switches profiles from icon menu
+ SWITCH_PROFILE_MENU, // User switches profiles from menu bar
+ SWITCH_PROFILE_DOCK, // User switches profiles from dock (Mac-only)
+ OPEN_USER_MANAGER, // User opens the User Manager
+ SWITCH_PROFILE_MANAGER, // User switches profiles from the User Manager
+ SWITCH_PROFILE_UNLOCK, // User switches to locked profile via User Manager
+ SWITCH_PROFILE_GUEST, // User switches to guest profile
+ SWITCH_PROFILE_CONTEXT_MENU, // User switches profiles from context menu
NUM_PROFILE_OPEN_METRICS
};
« no previous file with comments | « chrome/browser/profiles/profile_info_interface.h ('k') | chrome/browser/renderer_context_menu/render_view_context_menu.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698